@@ -141,6 +141,7 @@ Miscellaneous
 * Press 'w' to toggle wrapping of long lines
 * Press '=' to toggle showing the status bar at the bottom
 * Press 'v' to edit the file in your favorite editor
+* Press CTRL-t to change the tab size
 
 Moving around
 -------------
@@ -158,6 +159,7 @@ Moving around
 * < / 'gg' to go to the start of the document
 * > / 'G' to go to the end of the document
 * Half page 'u'p / 'd'own, or CTRL-u / CTRL-d
+* CTRL-a moves to the leftmost position
 * RETURN moves down one line
 
 Switching files (if you opened multiple files)
@@ -204,10 +206,10 @@ func NewPager(readers ...*reader.ReaderImpl) *Pager {
 	}
 
 	var name string
-	if readers[0] == nil || readers[0].Name == nil || len(*readers[0].Name) == 0 {
+	if readers[0] == nil || readers[0].DisplayName == nil || len(*readers[0].DisplayName) == 0 {
 		name = "Pager"
 	} else {
-		name = "Pager " + *readers[0].Name
+		name = "Pager " + *readers[0].DisplayName
 	}
 
 	pager := Pager{
