@@ -3,6 +3,7 @@ package reader
 import (
 	"regexp"
 
+	"github.com/rivo/uniseg"
 	"github.com/walles/moor/v2/internal/linemetadata"
 	"github.com/walles/moor/v2/internal/textstyles"
 	"github.com/walles/moor/v2/twin"
@@ -21,3 +22,11 @@ func (nl *NumberedLine) Plain() string {
 func (nl *NumberedLine) HighlightedTokens(plainTextStyle twin.Style, searchHitStyle twin.Style, searchHitLineBackground *twin.Color, search *regexp.Regexp) textstyles.StyledRunesWithTrailer {
 	return nl.Line.HighlightedTokens(plainTextStyle, searchHitStyle, searchHitLineBackground, search, &nl.Index)
 }
+
+func (nl *NumberedLine) DisplayWidth() int {
+	width := 0
+	for _, r := range nl.Plain() {
+		width += uniseg.StringWidth(string(r))
+	}
+	return width
+}
